==> smartconference_2.0-3.tar.gz: smartconference-2.0/pack.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#from glob import glob
import py2deb
import os

if __name__ == "__main__":

     	try:
         	os.chdir(os.path.dirname(sys.argv[0]))
     	except:
         	pass

     	print

	p=py2deb.Py2deb("smartconference")

	p.author="Alexey Kashevnik, Sitaev Michael, Yuras Valchenko"
	p.mail="alexey@iias.spb.su"
	p.description="Application for intelligent conference organisation"
	p.url = "http://www.spiiras.nw.ru/"
	p.depends = "python-gtk2|python2.5-gtk2, python-hildon|python2.5-hildon, kmplayer|vlc, python-dbus|python2.5-dbus, python-imaging|python2.5-imaging"
	p.section="user/tools"
	p.license="gpl"
	p.icon = "/home/user/MyDocs/agenda_project/agenda.png"
	p.arch="all"                #should be all for python, any for all arch
	p.urgency="low"             #not used in maemo onl for deb os
	p.distribution="chinook,diablo,fremantle"
	p.repository="extras-devel"
	p.xsbc_bugtracker="http://bugs.maemo.org"



	version = "2.0"           #Version of your software, e.g. "1.2.0" or "0.8.2"
	build = "3"                
	changeloginformation = "Alpha version" 
	dir_name = "src"            
	for root, dirs, files in os.walk(dir_name):
		real_dir = root[len(dir_name):]
	 	fake_file = []
	 	for f in files:
	     		fake_file.append(root + os.sep + f + "|" + f)
	 	if len(fake_file) > 0:
	     		p[real_dir] = fake_file
	print p
	r = p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)
	p.generate(version,build,build=True)




	#p["/opt/agenda_project"] = ["agenda_project.py","_functions.py","merge.py","settings.py","translator.py","user_profile.py","openpdf.sh"]
	#p["/scr/opt/agenda_project/src"] = ["camera.png","agenda1.5.glade","Image04.glade","data.txt"]
	#p["/src/usr/share/applications/hildon"] = ["agenda_project.desktop"]
	#p["/src/usr/share/dbus-1/services"] = ["agenda_project.service"]
	#p["/src/usr/share/icons/hicolor/48x48/hildon"] = ["badge48.png"]
	#p["/src/usr/share/icons/hicolor/scalable/hildon"] = ["badge64.png"]


	#p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)

==> smartconference_2.0-6.tar.gz: smartconference-2.0/pack.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#from glob import glob
import py2deb
import os

if __name__ == "__main__":

     	try:
         	os.chdir(os.path.dirname(sys.argv[0]))
     	except:
         	pass

     	print

	p=py2deb.Py2deb("smartconference")

	p.author="Alexey Kashevnik, Sitaev Michael, Yuras Valchenko"
	p.mail="alexey@iias.spb.su"
	p.description="Application for intelligent conference organisation"
	p.url = "http://www.spiiras.nw.ru/"
	p.depends = "python-gtk2|python2.5-gtk2, python-hildon|python2.5-hildon, kmplayer|vlc, python-dbus|python2.5-dbus, python-imaging|python2.5-imaging"
	p.section="user/tools"
	p.license="gpl"
	p.icon = "/home/user/MyDocs/agenda_project/agenda.png"
	p.arch="all"                #should be all for python, any for all arch
	p.urgency="low"             #not used in maemo onl for deb os
	p.distribution="chinook,diablo"
	p.repository="extras-devel"
	p.xsbc_bugtracker="http://bugs.maemo.org"



	version = "2.0"           #Version of your software, e.g. "1.2.0" or "0.8.2"
	build = "4"                
	changeloginformation = "Alpha version" 
	dir_name = "src"            
	for root, dirs, files in os.walk(dir_name):
		real_dir = root[len(dir_name):]
	 	fake_file = []
	 	for f in files:
	     		fake_file.append(root + os.sep + f + "|" + f)
	 	if len(fake_file) > 0:
	     		p[real_dir] = fake_file
	print p
	r = p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)
	p.generate(version,build,build=True)




	#p["/opt/agenda_project"] = ["agenda_project.py","_functions.py","merge.py","settings.py","translator.py","user_profile.py","openpdf.sh"]
	#p["/scr/opt/agenda_project/src"] = ["camera.png","agenda1.5.glade","Image04.glade","data.txt"]
	#p["/src/usr/share/applications/hildon"] = ["agenda_project.desktop"]
	#p["/src/usr/share/dbus-1/services"] = ["agenda_project.service"]
	#p["/src/usr/share/icons/hicolor/48x48/hildon"] = ["badge48.png"]
	#p["/src/usr/share/icons/hicolor/scalable/hildon"] = ["badge64.png"]


	#p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)
